@@ -2,7 +2,8 @@
 #'
 #' @templateVar plans TRUE
 #' @templateVar shp TRUE
-#' @param use_Rcpp Logical. Use Rcpp?
+#' @param use_Rcpp If `TRUE` (the default for more than 8 plans), precompute boundaries 
+#'   shared by each pair of units and use them to quickly compute the compactness score.
 #' @param perim_path path to perimeter tibble saved by `prep_perims()`
 #' @param perim_df tibble of perimeters from `prep_perims()`
 #' @templateVar epsg TRUE
@@ -34,7 +35,11 @@ comp_polsby <- function(plans, shp, use_Rcpp, perim_path, perim_df, epsg = 3857,
 
   # process objects ----
   shp <- planarize(shp, epsg)
-  shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  if (ncores > 1) {
+    shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  } else {
+    shp_col <- geos::geos_make_collection(geos::as_geos_geometry(shp))
+  }
   plans <- process_plans(plans)
   n_plans <- ncol(plans)
   dists <- sort(unique(c(plans)))
@@ -132,7 +137,11 @@ comp_schwartz <- function(plans, shp, use_Rcpp, perim_path, perim_df, epsg = 385
 
   # process objects ----
   shp <- planarize(shp, epsg)
-  shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  if (ncores > 1) {
+    shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  } else {
+    shp_col <- geos::geos_make_collection(geos::as_geos_geometry(shp))
+  }
   plans <- process_plans(plans)
   n_plans <- ncol(plans)
   dists <- sort(unique(c(plans)))
@@ -227,7 +236,11 @@ comp_reock <- function(plans, shp, epsg = 3857, ncores = 1) {
 
   # process objects ----
   shp <- planarize(shp, epsg)
-  shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  if (ncores > 1) {
+    shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  } else {
+    shp_col <- geos::geos_make_collection(geos::as_geos_geometry(shp))
+  }
   plans <- process_plans(plans)
   n_plans <- ncol(plans)
   dists <- sort(unique(c(plans)))
@@ -289,7 +302,11 @@ comp_ch <- function(plans, shp, epsg = 3857, ncores = 1) {
 
   # process objects ----
   shp <- planarize(shp, epsg)
-  shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  if (ncores > 1) {
+    shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  } else {
+    shp_col <- geos::geos_make_collection(geos::as_geos_geometry(shp))
+  }
   plans <- process_plans(plans)
   n_plans <- ncol(plans)
   dists <- sort(unique(c(plans)))
@@ -424,7 +441,11 @@ comp_bc <- function(plans, shp, epsg = 3857, ncores = 1) {
   # process objects ----
   shp <- planarize(shp, epsg)
   epsg <- sf::st_crs(shp)$epsg
-  shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  if (ncores > 1) {
+    shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  } else {
+    shp_col <- geos::geos_make_collection(geos::as_geos_geometry(shp))
+  }
   plans <- process_plans(plans)
   n_plans <- ncol(plans)
   dists <- sort(unique(c(plans)))
@@ -688,7 +709,11 @@ comp_skew <- function(plans, shp, epsg = 3857, ncores = 1) {
 
   # process objects ----
   shp <- planarize(shp, epsg)
-  shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  if (ncores > 1) {
+    shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  } else {
+    shp_col <- geos::geos_make_collection(geos::as_geos_geometry(shp))
+  }
   plans <- process_plans(plans)
   n_plans <- ncol(plans)
   dists <- sort(unique(c(plans)))
@@ -754,7 +779,11 @@ comp_box_reock <- function(plans, shp, epsg = 3857, ncores = 1) {
 
   # process objects ----
   shp <- planarize(shp, epsg)
-  shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  if (ncores > 1) {
+    shp_col <- wk::as_wkt(geos::geos_make_collection(geos::as_geos_geometry(shp)))
+  } else {
+    shp_col <- geos::geos_make_collection(geos::as_geos_geometry(shp))
+  }
   plans <- process_plans(plans)
   n_plans <- ncol(plans)
   dists <- sort(unique(c(plans)))
